Traits
- Bind
Value - Converts a Rust value into a dialect value while checking SQL marker assignment.
- Nullable
Bind Value - Converts an optional Rust value into a nullable dialect value.
- Value
Type ForDialect - Maps a Rust value type to its SQL marker for a specific dialect.