pub trait ExcludedSupport { }Expand description
Dialects whose upsert syntax exposes the proposed row as EXCLUDED.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".
pub trait ExcludedSupport { }Dialects whose upsert syntax exposes the proposed row as EXCLUDED.
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".