pub trait HasAggStatus {
type Status;
}Expand description
Extract the aggregate status of a type that appears in a SELECT list.
Implemented for column ZSTs (always Scalar), SQLExpr, and expression wrappers.
pub trait HasAggStatus {
type Status;
}Extract the aggregate status of a type that appears in a SELECT list.
Implemented for column ZSTs (always Scalar), SQLExpr, and expression wrappers.