MathExt

Trait MathExt 

pub trait MathExt { }
Dialects that provide the optional math functions.

CEIL, FLOOR, TRUNC, SQRT, POWER, EXP, LN, LOG, LOG10, LOG2 and PI are built into PostgreSQL and MySQL. SQLite has them only when it is compiled with SQLITE_ENABLE_MATH_FUNCTIONS, which the bundled rusqlite and libsql builds do not set. Enabling the math cargo feature says that the linked SQLite has them. Without it, these functions do not compile for SQLite, instead of failing at runtime with “no such function”.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors