StatisticalAggregatePolicy

Trait StatisticalAggregatePolicy 

pub trait StatisticalAggregatePolicy<D>: Numeric {
    type StddevPop: DataType;
    type StddevSamp: DataType;
    type VarPop: DataType;
    type VarSamp: DataType;
}
Result types of the standard deviation and variance aggregates for a numeric SQL type on dialect D.

On PostgreSQL every result is float8; on MySQL it is DOUBLE. SQLite has no built-in statistical aggregates, so it does not implement this trait.

Required Associated Types

type StddevPop: DataType

Result type of STDDEV_POP.

type StddevSamp: DataType

Result type of STDDEV_SAMP.

type VarPop: DataType

Result type of VAR_POP.

type VarSamp: DataType

Result type of VAR_SAMP / VARIANCE.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl StatisticalAggregatePolicy<MySQLDialect> for BigInt

Source

impl StatisticalAggregatePolicy<MySQLDialect> for BigIntUnsigned

Source

impl StatisticalAggregatePolicy<MySQLDialect> for Decimal

Source

impl StatisticalAggregatePolicy<MySQLDialect> for Double

Source

impl StatisticalAggregatePolicy<MySQLDialect> for Float

Source

impl StatisticalAggregatePolicy<MySQLDialect> for Int

Source

impl StatisticalAggregatePolicy<MySQLDialect> for IntUnsigned

Source

impl StatisticalAggregatePolicy<MySQLDialect> for MediumInt

Source

impl StatisticalAggregatePolicy<MySQLDialect> for MediumIntUnsigned

Source

impl StatisticalAggregatePolicy<MySQLDialect> for SmallInt

Source

impl StatisticalAggregatePolicy<MySQLDialect> for SmallIntUnsigned

Source

impl StatisticalAggregatePolicy<MySQLDialect> for TinyInt

Source

impl StatisticalAggregatePolicy<MySQLDialect> for TinyIntUnsigned

Source

impl StatisticalAggregatePolicy<MySQLDialect> for Year

Source

impl StatisticalAggregatePolicy<PostgresDialect> for Float4

Source

impl StatisticalAggregatePolicy<PostgresDialect> for Float8

Source

impl StatisticalAggregatePolicy<PostgresDialect> for Int2

Source

impl StatisticalAggregatePolicy<PostgresDialect> for Int4

Source

impl StatisticalAggregatePolicy<PostgresDialect> for Int8

Source

impl StatisticalAggregatePolicy<PostgresDialect> for Numeric

Implementors