pub trait DecodeSelectedRef<RowRef, R> {
// Required method
fn decode(row: RowRef) -> Result<R, DrizzleError>;
}Expand description
Marker-directed row decoding for .all()/.get().
Required Methods
Sourcefn decode(row: RowRef) -> Result<R, DrizzleError>
fn decode(row: RowRef) -> Result<R, DrizzleError>
Decode the row into R according to the marker.
Errors
Returns an error if the row cannot be decoded into the expected type (missing columns, type mismatch, or downstream conversion failure).
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".