pub trait ResolveRow<Table> {
type Row;
}Expand description
Given a select marker and a table, determines the default row type R.
Evaluated at .from(table) time.
pub trait ResolveRow<Table> {
type Row;
}Given a select marker and a table, determines the default row type R.
Evaluated at .from(table) time.