RowColumnList

Trait RowColumnList 

pub trait RowColumnList<Row: ?Sized> {
    type Columns: TypeSet;
}
Type-level column-list representation for a row decode target.

Each consumed column is represented by a Cons<T, ...> node where T is the decoded Rust type for that column.

Required Associated Types

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<Row: ?Sized, A, B, C, D, E, F, G, H> RowColumnList<Row> for (A, B, C, D, E, F, G, H)

Source

impl<Row: ?Sized, A, B, C, D, E, F, G> RowColumnList<Row> for (A, B, C, D, E, F, G)

Source

impl<Row: ?Sized, A, B, C, D, E, F> RowColumnList<Row> for (A, B, C, D, E, F)

Source

impl<Row: ?Sized, A, B, C, D, E> RowColumnList<Row> for (A, B, C, D, E)

Source

impl<Row: ?Sized, A, B, C, D> RowColumnList<Row> for (A, B, C, D)
where A: RowColumnList<Row>, B: RowColumnList<Row>, C: RowColumnList<Row>, D: RowColumnList<Row>, (A, B, C): RowColumnList<Row>, <(A, B, C) as RowColumnList<Row>>::Columns: Concat<<D as RowColumnList<Row>>::Columns>,

Source

impl<Row: ?Sized, A, B, C> RowColumnList<Row> for (A, B, C)
where A: RowColumnList<Row>, B: RowColumnList<Row>, C: RowColumnList<Row>, <A as RowColumnList<Row>>::Columns: Concat<<B as RowColumnList<Row>>::Columns>, <<A as RowColumnList<Row>>::Columns as Concat<<B as RowColumnList<Row>>::Columns>>::Output: Concat<<C as RowColumnList<Row>>::Columns>,

Source

type Columns = <<<A as RowColumnList<Row>>::Columns as Concat<<B as RowColumnList<Row>>::Columns>>::Output as Concat<<C as RowColumnList<Row>>::Columns>>::Output

Source

impl<Row: ?Sized, A, B> RowColumnList<Row> for (A, B)
where A: RowColumnList<Row>, B: RowColumnList<Row>, <A as RowColumnList<Row>>::Columns: Concat<<B as RowColumnList<Row>>::Columns>,

Source

type Columns = <<A as RowColumnList<Row>>::Columns as Concat<<B as RowColumnList<Row>>::Columns>>::Output

Source

impl<Row: ?Sized, A: Array> RowColumnList<Row> for SmallVec<A>

Source

impl<Row: ?Sized, A> RowColumnList<Row> for (A,)
where A: RowColumnList<Row>,

Source

impl<Row: ?Sized, T> RowColumnList<Row> for Option<T>

Source

impl<Row: ?Sized> RowColumnList<Row> for ()

Source

impl<Row: ?Sized> RowColumnList<Row> for CompactString

Source

impl<Row: ?Sized> RowColumnList<Row> for String

Source

impl<Row: ?Sized> RowColumnList<Row> for Vec<u8>

Source

impl<Row: ?Sized> RowColumnList<Row> for bool

Source

impl<Row: ?Sized> RowColumnList<Row> for f32

Source

impl<Row: ?Sized> RowColumnList<Row> for f64

Source

impl<Row: ?Sized> RowColumnList<Row> for i8

Source

impl<Row: ?Sized> RowColumnList<Row> for i16

Source

impl<Row: ?Sized> RowColumnList<Row> for i32

Source

impl<Row: ?Sized> RowColumnList<Row> for i64

Source

impl<Row: ?Sized> RowColumnList<Row> for isize

Source

impl<Row: ?Sized> RowColumnList<Row> for u8

Source

impl<Row: ?Sized> RowColumnList<Row> for u16

Source

impl<Row: ?Sized> RowColumnList<Row> for u32

Source

impl<Row: ?Sized> RowColumnList<Row> for u64

Source

impl<Row: ?Sized> RowColumnList<Row> for usize

Implementors