pub trait SelectSources {
type Sources;
}Expand description
Sources a SELECT reads when it is used as a subquery expression.
A scoped query resolves its clauses and projection against its own
FROM/JOIN scope first (At); whatever does not resolve there must be a
source of the enclosing query (a correlated reference).
Required Associated Types
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".