SetOperand

Trait SetOperand 

pub trait SetOperand<Other> {
    type Combined;
}
The marker of a compound query (UNION, INTERSECT, EXCEPT) built from a query with marker Self and an operand with marker Other.

The compound decodes like the left query. The operand’s sources are kept so the compound is scope-checked as a whole.

Required Associated Types

type Combined

The marker of the compound query.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<Cols, Other> SetOperand<Other> for SelectCols<Cols>

Source

impl<M, Scope, Used, Other: SelectSources> SetOperand<Other> for Scoped<M, Scope, Used>

Source

type Combined = Scoped<M, Scope, (Used, <Other as SelectSources>::Sources)>

Source

impl<Other> SetOperand<Other> for SelectExpr

Source

impl<Other> SetOperand<Other> for SelectStar

Source

impl<R, Other> SetOperand<Other> for SelectAs<R>