Token

Enum Token 

pub enum Token {
Show 177 variants ABORT, ACTION, ADD, AFTER, ALL, ALTER, ALWAYS, ANALYZE, AND, ANY, AS, ASC, ATTACH, AUTOINCR, BEFORE, BEGIN, BETWEEN, BITAND, BITNOT, BITOR, BLOB, BY, CASCADE, CASE, CAST, CHECK, COLLATE, COLUMN, COMMA, COMMIT, CONCAT, CONCURRENTLY, CONFLICT, CONSTRAINT, CREATE, CTIME, CURRENT, DATA, DATABASE, DEFAULT, DEFERRABLE, DEFERRED, DELETE, DESC, DETACH, DISTINCT, DO, DOT, DROP, DUPLICATE, EACH, ELSE, END, EOF, EQ, ESCAPE, EXCEPT, EXCLUDE, EXCLUDED, EXCLUSIVE, EXISTS, EXPLAIN, FAIL, FILTER, FIRST, FLOAT, FOLLOWING, FOR, FOREIGN, FROM, GE, GENERATED, GROUP, GROUPS, GT, HAVING, ID, IF, IGNORE, ILLEGAL, IMMEDIATE, IN, INDEX, INDEXED, INITIALLY, INSERT, INSTEAD, INTEGER, INTERSECT, INTO, IS, ISNOT, ISNULL, JOIN, KEY, LAST, LE, LIKE, LIMIT, LOCKED, LPAREN, LSHIFT, LT, MATCH, MATERIALIZED, MINUS, NE, NO, NOT, NOTHING, NOTNULL, NOWAIT, NULL, NULLS, OF, OFFSET, ON, OR, ORDER, OTHERS, OVER, PARTITION, PLAN, PLUS, PRAGMA, PRECEDING, PRIMARY, PTR, QUERY, RAISE, RANGE, RECURSIVE, REFRESH, REFERENCES, REINDEX, RELEASE, REM, RENAME, REPLACE, RESTRICT, RETURNING, ROLLBACK, ROW, ROWS, RPAREN, RSHIFT, SAVEPOINT, SELECT, SEMI, SET, SHARE, SKIP, SLASH, STAR, STRING, TABLE, TEMP, THEN, TIES, TO, TRANSACTION, TRIGGER, UNBOUNDED, UNION, UNIQUE, UPDATE, USING, VACUUM, VALUES, VARIABLE, VIEW, VIRTUAL, WHEN, WHERE, WINDOW, WITH, WITHOUT,
}
A SQL keyword, operator, or punctuation mark.

Each variant renders as fixed text (see Token::as_str). Most render as their own name; operators and punctuation render as symbols, for example EQ as =, LPAREN as (, and CONCAT as ||.

Examples

use drizzle_core::Token;

assert_eq!(Token::SELECT.as_str(), "SELECT");
assert_eq!(Token::NE.as_str(), "<>");

Variants



ABORT



ACTION



ADD



AFTER



ALL



ALTER



ALWAYS



ANALYZE



AND



ANY



AS



ASC



ATTACH



AUTOINCR



BEFORE



BEGIN



BETWEEN



BITAND



BITNOT



BITOR



BLOB



BY



CASCADE



CASE



CAST



CHECK



COLLATE



COLUMN



COMMA



COMMIT



CONCAT



CONCURRENTLY



CONFLICT



CONSTRAINT



CREATE



CTIME



CURRENT



DATA



DATABASE



DEFAULT



DEFERRABLE



DEFERRED



DELETE



DESC



DETACH



DISTINCT



DO



DOT



DROP



DUPLICATE



EACH



ELSE



END



EOF



EQ



ESCAPE



EXCEPT



EXCLUDE



EXCLUDED



EXCLUSIVE



EXISTS



EXPLAIN



FAIL



FILTER



FIRST



FLOAT



FOLLOWING



FOR



FOREIGN



FROM



GE



GENERATED



GROUP



GROUPS



GT



HAVING



ID



IF



IGNORE



ILLEGAL



IMMEDIATE



IN



INDEX



INDEXED



INITIALLY



INSERT



INSTEAD



INTEGER



INTERSECT



INTO



IS



ISNOT



ISNULL



JOIN



KEY



LAST



LE



LIKE



LIMIT



LOCKED



LPAREN



LSHIFT



LT



MATCH



MATERIALIZED



MINUS



NE



NO



NOT



NOTHING



NOTNULL



NOWAIT



NULL



NULLS



OF



OFFSET



ON



OR



ORDER



OTHERS



OVER



PARTITION



PLAN



PLUS



PRAGMA



PRECEDING



PRIMARY



PTR



QUERY



RAISE



RANGE



RECURSIVE



REFRESH



REFERENCES



REINDEX



RELEASE



REM



RENAME



REPLACE



RESTRICT



RETURNING



ROLLBACK



ROW



ROWS



RPAREN



RSHIFT



SAVEPOINT



SELECT



SEMI



SET



SHARE



SKIP



SLASH



STAR



STRING



TABLE



TEMP



THEN



TIES



TO



TRANSACTION



TRIGGER



UNBOUNDED



UNION



UNIQUE



UPDATE



USING



VACUUM



VALUES



VARIABLE



VIEW



VIRTUAL



WHEN



WHERE



WINDOW



WITH



WITHOUT

Implementations

Source

impl Token

pub const fn is_operator(&self) -> bool

Returns true for operators, which are rendered with a space on each side (=, +, ||, …).

pub const fn is_punctuation(&self) -> bool

Returns true for punctuation ((, ), ,, ;, .), which is not spaced like a word.

pub const fn as_str(&self) -> &'static str

Returns the SQL text of this token.