DrizzleTable

Trait DrizzleTable 

pub trait DrizzleTable:
    Send
    + Sync
    + 'static {
    const NAME: &'static str;
    const QUALIFIED_NAME: &'static str;
    const TABLE_REF: TableRef;
    const SCHEMA: Option<&'static str> = None;
    const DEPENDENCY_NAMES: &'static [&'static str] = _;
}
Compile-time table metadata.

Provides table name, schema, columns, keys, and constraints as associated constants. Implementing this trait automatically provides SQLTableInfo via a blanket implementation.

Required Associated Constants

const NAME: &'static str

Unqualified table name.

const QUALIFIED_NAME: &'static str

Fully-qualified table name (e.g. schema.table).

const TABLE_REF: TableRef

Full table metadata as a const Copy struct.

Provided Associated Constants

const SCHEMA: Option<&'static str> = None

Schema namespace, if any.

const DEPENDENCY_NAMES: &'static [&'static str] = _

Names of tables this table depends on via foreign keys.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors