pub fn between<'a, V, E, L, H>(
expr: E,
low: L,
high: H,
) -> SQLExpr<'a, V, <V::DialectMarker as DialectTypes>::Bool, NonNull, <<E::Aggregate as AggOr<<L as ComparisonOperand<'a, V, E>>::Aggregate>>::Output as AggOr<<H as ComparisonOperand<'a, V, E>>::Aggregate>>::Output>where
V: SQLParam + 'a,
E: Expr<'a, V>,
L: ComparisonOperand<'a, V, E>,
H: ComparisonOperand<'a, V, E>,
E::SQLType: Compatible<<L as ComparisonOperand<'a, V, E>>::SQLType> + Compatible<<H as ComparisonOperand<'a, V, E>>::SQLType>,
E::Aggregate: AggOr<<L as ComparisonOperand<'a, V, E>>::Aggregate>,
<E::Aggregate as AggOr<<L as ComparisonOperand<'a, V, E>>::Aggregate>>::Output: AggOr<<H as ComparisonOperand<'a, V, E>>::Aggregate>,Expand description
BETWEEN comparison.
Checks if expr is between low and high (inclusive). Requires expr type to be compatible with both bounds.