left

Function left 

pub fn left<'a, V, E, N>(
    expr: E,
    n: N,
) -> SQLExpr<'a, V, <V::DialectMarker as DialectTypes>::Text, <E::Nullable as NullOr<N::Nullable>>::Output, <E::Aggregate as AggOr<N::Aggregate>>::Output>
LEFT - returns the first n characters of a string (PostgreSQL and MySQL).

The result is nullable when either argument is nullable.

Example

use drizzle_core::expr::left;

// SELECT LEFT(users.name, 3)
let prefix = left(users.name, 3);