replace

Function replace 

pub fn replace<'a, V, E, F, T>(
    expr: E,
    from: F,
    to: T,
) -> SQLExpr<'a, V, <V::DialectMarker as DialectTypes>::Text, <<E::Nullable as NullOr<F::Nullable>>::Output as NullOr<T::Nullable>>::Output, <<E::Aggregate as AggOr<F::Aggregate>>::Output as AggOr<T::Aggregate>>::Output>
REPLACE - replaces occurrences of a substring.

Replaces all occurrences of from with to in the expression. The result is nullable when any argument is nullable.

Example

use drizzle_core::expr::replace;

// SELECT REPLACE(users.email, '@old.com', '@new.com')
let new_email = replace(users.email, "@old.com", "@new.com");