pub struct WindowFnExpr<'a, V: SQLParam, T: DataType, N: Nullability> { /* private fields */ }Expand description
A window function expression that is not yet valid SQL.
Pure window functions like ROW_NUMBER, RANK, LAG, etc. MUST have an
.over() call before they can be used in a query. This type enforces
that at compile time by not implementing Expr or ToSQL.
Implementations
Sourceimpl<'a, V, T, N> WindowFnExpr<'a, V, T, N>
impl<'a, V, T, N> WindowFnExpr<'a, V, T, N>
Sourcepub fn over(self, spec: WindowSpec<'a, V>) -> SQLExpr<'a, V, T, N, Scalar>
pub fn over(self, spec: WindowSpec<'a, V>) -> SQLExpr<'a, V, T, N, Scalar>
Apply a window specification, producing a usable scalar expression.
Generates <fn> OVER (...).