pub trait ConditionList<'a, V: SQLParam>: Sealed + ExprSources {
type Nullable: Nullability;
type Aggregate: AggregateKind;
}Expand description
A tuple of conditions that all and any can combine.
Implemented for tuples of 1 to 8 elements (16 with the col16 feature,
which is on by default). Each element is a boolean expression or an
Option of one. The list is nullable if any element is nullable, and is
an aggregate if any element is.
Tuples of up to 8 elements are also conditions themselves (they implement
Expr). For longer lists, use all or any, or nest
tuples.
This trait is sealed.
Required Associated Types
Sourcetype Nullable: Nullability
type Nullable: Nullability
Nullability folded across every element.
Sourcetype Aggregate: AggregateKind
type Aggregate: AggregateKind
Aggregate kind folded across every element.
Dyn Compatibility
This trait is dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".