MathExt

Trait MathExt 

pub trait MathExt { }
Math functions that are optional on SQLite.

CEIL, FLOOR, TRUNC, SQRT, POWER, EXP, LN, LOG, LOG10, LOG2 and PI are built into PostgreSQL and MySQL, but SQLite only has them when it is compiled with SQLITE_ENABLE_MATH_FUNCTIONS, which the bundled rusqlite and libsql builds do not set. The math cargo feature is the promise that the linked SQLite provides them; without it these functions do not type-check for SQLite instead of failing at runtime with “no such function”.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors