pub trait StatisticalAggregatePolicy<D>: Numeric {
type StddevPop: DataType;
type StddevSamp: DataType;
type VarPop: DataType;
type VarSamp: DataType;
}Expand description
Result types of the standard deviation and variance aggregates for a
numeric SQL type on dialect D.
On PostgreSQL every result is float8; on MySQL it is DOUBLE. SQLite
has no built-in statistical aggregates, so it does not implement this
trait.
Required Associated Types
Sourcetype StddevSamp: DataType
type StddevSamp: DataType
Result type of STDDEV_SAMP.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".