RowColumnList

Trait RowColumnList 

pub trait RowColumnList<Row: ?Sized> {
    type Columns: TypeSet;
}
The columns a decode target reads, as a type-level list.

Each column is one Cons<T, ...> node, where T is the Rust type it decodes into. Tuples concatenate their elements’ lists.

Required Associated Types

type Columns: TypeSet

Cons<T0, Cons<T1, ... Nil>>.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<Row: ?Sized, A: Array> RowColumnList<Row> for SmallVec<A>

Source

impl<Row: ?Sized, T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15> RowColumnList<Row> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14, T15)

Source

impl<Row: ?Sized, T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14> RowColumnList<Row> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13, T14)

Source

impl<Row: ?Sized, T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13> RowColumnList<Row> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12, T13)

Source

impl<Row: ?Sized, T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12> RowColumnList<Row> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11, T12)

Source

impl<Row: ?Sized, T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11> RowColumnList<Row> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10, T11)

Source

impl<Row: ?Sized, T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10> RowColumnList<Row> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9, T10)

Source

impl<Row: ?Sized, T0, T1, T2, T3, T4, T5, T6, T7, T8, T9> RowColumnList<Row> for (T0, T1, T2, T3, T4, T5, T6, T7, T8, T9)

Source

impl<Row: ?Sized, T0, T1, T2, T3, T4, T5, T6, T7, T8> RowColumnList<Row> for (T0, T1, T2, T3, T4, T5, T6, T7, T8)

Source

impl<Row: ?Sized, T0, T1, T2, T3, T4, T5, T6, T7> RowColumnList<Row> for (T0, T1, T2, T3, T4, T5, T6, T7)

Source

impl<Row: ?Sized, T0, T1, T2, T3, T4, T5, T6> RowColumnList<Row> for (T0, T1, T2, T3, T4, T5, T6)

Source

impl<Row: ?Sized, T0, T1, T2, T3, T4, T5> RowColumnList<Row> for (T0, T1, T2, T3, T4, T5)

Source

impl<Row: ?Sized, T0, T1, T2, T3, T4> RowColumnList<Row> for (T0, T1, T2, T3, T4)

Source

impl<Row: ?Sized, T0, T1, T2, T3> RowColumnList<Row> for (T0, T1, T2, T3)

Source

impl<Row: ?Sized, T0, T1, T2> RowColumnList<Row> for (T0, T1, T2)
where T2: RowColumnList<Row>, (T0, T1): RowColumnList<Row>, <(T0, T1) as RowColumnList<Row>>::Columns: Concat<<T2 as RowColumnList<Row>>::Columns>,

Source

impl<Row: ?Sized, T0, T1> RowColumnList<Row> for (T0, T1)
where T1: RowColumnList<Row>, (T0,): RowColumnList<Row>, <(T0,) as RowColumnList<Row>>::Columns: Concat<<T1 as RowColumnList<Row>>::Columns>,

Source

impl<Row: ?Sized, T0: RowColumnList<Row>> RowColumnList<Row> for (T0,)

Source

impl<Row: ?Sized, T> RowColumnList<Row> for Option<T>

Source

impl<Row: ?Sized> RowColumnList<Row> for ()

Source

impl<Row: ?Sized> RowColumnList<Row> for CompactString

Source

impl<Row: ?Sized> RowColumnList<Row> for String

Source

impl<Row: ?Sized> RowColumnList<Row> for Vec<u8>

Source

impl<Row: ?Sized> RowColumnList<Row> for bool

Source

impl<Row: ?Sized> RowColumnList<Row> for f32

Source

impl<Row: ?Sized> RowColumnList<Row> for f64

Source

impl<Row: ?Sized> RowColumnList<Row> for i8

Source

impl<Row: ?Sized> RowColumnList<Row> for i16

Source

impl<Row: ?Sized> RowColumnList<Row> for i32

Source

impl<Row: ?Sized> RowColumnList<Row> for i64

Source

impl<Row: ?Sized> RowColumnList<Row> for isize

Source

impl<Row: ?Sized> RowColumnList<Row> for u8

Source

impl<Row: ?Sized> RowColumnList<Row> for u16

Source

impl<Row: ?Sized> RowColumnList<Row> for u32

Source

impl<Row: ?Sized> RowColumnList<Row> for u64

Source

impl<Row: ?Sized> RowColumnList<Row> for usize

Implementors